# 🪵 Changelog

## [0.0.1](https://github.com/vemonet/openroute-mcp/tree/v0.0.1) - 2025-10-08

### ⛰️ Features

- Initial commit - ([bd92846](https://github.com/vemonet/openroute-mcp/commit/bd92846aa6c804a2ddbc5003d1643bc169b312da))
- Add `search_pois` tool - ([56532d6](https://github.com/vemonet/openroute-mcp/commit/56532d68f226d141e9285f194a7e8a926f7713df))
- Properly generate and return as resource a PNG image of the route, and a HTML file to visualize the route with openstreetmap - ([a7848cc](https://github.com/vemonet/openroute-mcp/commit/a7848cccbb10d16495ad7a9bd45f13c7299cf4af))
- Add `get_coordinates_object` and `get_reachable_area` tools - ([267fded](https://github.com/vemonet/openroute-mcp/commit/267fded7265acffdbcaf1a0bd5e33157def761f8))

### 📚 Documentation

- Update readme - ([e65be2b](https://github.com/vemonet/openroute-mcp/commit/e65be2b07189f1d0f1d387e7075d9777fc88e142))

<!-- generated by git-cliff -->
